django-email-phone-user
=======================

Django Custom User model with email or phone username.

.. image:: https://travis-ci.org/168estate/django-email-phone-user.png
    :target: https://travis-ci.org/168estate/django-email-phone-user
    :alt: Build Status

.. image:: https://coveralls.io/repos/168estate/django-email-phone-user/badge.png
    :target: https://coveralls.io/r/168estate/django-email-phone-user
    :alt: Coverage Status

.. image:: https://pypip.in/v/django-email-phone-user/badge.png
    :target: https://crate.io/packages/django-email-phone-user
    :alt: Version

.. image:: https://pypip.in/d/django-email-phone-user/badge.png
    :target: https://crate.io/packages/django-email-phone-user
    :alt: Downloads

.. image:: https://pypip.in/format/django-email-phone-user/badge.png
    :target: https://pypi.python.org/pypi/django-email-phone-user/
    :alt: Download format


.. image:: https://pypip.in/license/django-email-phone-user/badge.png
    :target: https://pypi.python.org/pypi/django-email-phone-user/
    :alt: License


Install
-------

.. code-block:: python

    pip install django-email-phone-user
